1.0.0 API documentation: matrix_float3x3.hpp Source File

| 1.0.0 API documentation

matrix_float3x3.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_mat3x3.hpp"
6
7 namespace glm
8 {
11
15 typedef mat<3, 3, float, defaultp> mat3x3;
16
20 typedef mat<3, 3, float, defaultp> mat3;
21
23 }//namespace glm
glm::mat3
mat< 3, 3, float, defaultp > mat3
3 columns of 3 components matrix of single-precision floating-point numbers.
Definition: matrix_float3x3.hpp:20
glm::mat3x3
mat< 3, 3, float, defaultp > mat3x3
3 columns of 3 components matrix of single-precision floating-point numbers.
Definition: matrix_float3x3.hpp:15